import { EventEmitter } from "node:events";
import type { DocumentAccessor } from "../../model/doc.ts";
import { type DiffWatcherEvent, type IDiffWatcher, linkWatcher } from "../watcher.ts";

export class WatcherFilter extends EventEmitter implements IDiffWatcher {
	refWatcher: IDiffWatcher;
	filter: (filename: string) => boolean;
	on<U extends keyof DiffWatcherEvent>(event: U, listener: DiffWatcherEvent[U]): this {
		return super.on(event, listener);
	}
	/**
	 * emit event
	 * @param event
	 * @param arg
	 * @returns `true` if the event had listeners, `false` otherwise.
	 */
	emit<U extends keyof DiffWatcherEvent>(event: U, ...arg: Parameters<DiffWatcherEvent[U]>): boolean {
		if (event === "change") {
			const prev = arg[0];
			const cur = arg[1] as string;
			if (this.filter(prev)) {
				if (this.filter(cur)) {
					return super.emit("change", prev, cur);
				}
					return super.emit("delete", cur);
			}
				if (this.filter(cur)) {
					return super.emit("create", cur);
				}
			return false;
		}
		if (!this.filter(arg[0])) {
			return false;
		}
		return super.emit(event, ...arg);
	}
	constructor(refWatcher: IDiffWatcher, filter: (filename: string) => boolean) {
		super();
		this.refWatcher = refWatcher;
		this.filter = filter;
		linkWatcher(refWatcher, this);
	}
	setup(cntr: DocumentAccessor): Promise<void> {
		return this.refWatcher.setup(cntr);
	}
}
